==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_front/spec/helpers/ec_rider/ec_helper/method_description_spec.rb <==
# -*- coding: utf-8 -*-
require File.dirname(__FILE__) + '/../../../spec_helper'

describe EcRider::EcHelper::MethodDescription do

  describe "desc" do

    module Test
      extend EcRider::EcHelper::MethodDescription

      desc <<-EOS
        [概要:画像リンクを表示します。]
        [引数 href(必須):画像を押したときの遷移先URLを指定します。]
        [引数 src(必須):画像ファイルのパスまたはURLを指定します。
          ファイルマネージャでアップロードしたファイルの場合、cmsフォルダは省略できます。]
        [引数 (オプション):画像のHTMLオプションを指定します。]
        [戻り値:画像リンク。]
        [使用例:
          * cmsフォルダを省略、HTMLオプションborderを指定
          {{{
            <ec:image_link src="logo.gif" href="/" border="1"/>
          }}}
          ⇒
          {{{
            <a href="/">
              <img border="1" src="/cms/logo.gif" alt="Logo"/>
            </a>
          }}}
        ]
      EOS
      def foo
      end

    end

    it "shoud format " do
      expectation = <<EOS
<tr><th>概要: </th><td>画像リンクを表示します。</td></tr>
<tr><th>引数 href(必須): </th><td>画像を押したときの遷移先URLを指定します。</td></tr>
<tr><th>引数 src(必須): </th><td>画像ファイルのパスまたはURLを指定します。<br/>
          ファイルマネージャでアップロードしたファイルの場合、cmsフォルダは省略できます。</td></tr>
<tr><th>引数 (オプション): </th><td>画像のHTMLオプションを指定します。</td></tr>
<tr><th>戻り値: </th><td>画像リンク。</td></tr>
<tr><th>使用例: </th><td>* cmsフォルダを省略、HTMLオプションborderを指定<br/><br/>  &lt;ec:image_link src=&quot;logo.gif&quot; href=&quot;/&quot; border=&quot;1&quot;/&gt;<br/><br/>⇒<br/><br/>  &lt;a href=&quot;/&quot;&gt;<br/>    &lt;img border=&quot;1&quot; src=&quot;/cms/logo.gif&quot; alt=&quot;Logo&quot;/&gt;<br/>  &lt;/a&gt;<br/></td></tr>
EOS
      Test.descriptions[:foo].gsub(/\n/,'').should == expectation.gsub(/\n/,'')
    end

  end

  def ec
    helper.ec
  end

  describe 'bind_code_options' do
    it 'バインドの項目選択セレクトボックス用リスト取得' do
      expected_number = EcRider::EcHelper::ProductTag::BIND_OPTION_METHODS.length +
                        EcRider::EcHelper::ShopTag::BIND_OPTION_METHODS.length +
                        EcRider::EcHelper::UserLoginTag::BIND_OPTION_METHODS.length
      result = EcRider::EcHelper::MethodDescription.bind_code_options
      result.length.should == expected_number
    end
  end

  describe 'bind_code_name' do
    it 'バインドの項目名取得' do
      EcRider::EcHelper::MethodDescription.bind_code_name('product_name_1').should == ['商品名1']
    end
  end
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_front/spec/helpers/ec_rider/ec_helper/method_description_spec.rb <==
# -*- coding: utf-8 -*-
require File.dirname(__FILE__) + '/../../../spec_helper'

describe EcRider::EcHelper::MethodDescription do

  describe "desc" do

    module Test
      extend EcRider::EcHelper::MethodDescription

      desc <<-EOS
        [概要:画像リンクを表示します。]
        [引数 href(必須):画像を押したときの遷移先URLを指定します。]
        [引数 src(必須):画像ファイルのパスまたはURLを指定します。
          ファイルマネージャでアップロードしたファイルの場合、cmsフォルダは省略できます。]
        [引数 (オプション):画像のHTMLオプションを指定します。]
        [戻り値:画像リンク。]
        [使用例:
          * cmsフォルダを省略、HTMLオプションborderを指定
          {{{
            <ec:image_link src="logo.gif" href="/" border="1"/>
          }}}
          ⇒
          {{{
            <a href="/">
              <img border="1" src="/cms/logo.gif" alt="Logo"/>
            </a>
          }}}
        ]
      EOS
      def foo
      end

    end

    it "shoud format " do
      expectation = <<EOS
<tr><th>概要: </th><td>画像リンクを表示します。</td></tr>
<tr><th>引数 href(必須): </th><td>画像を押したときの遷移先URLを指定します。</td></tr>
<tr><th>引数 src(必須): </th><td>画像ファイルのパスまたはURLを指定します。<br/>
          ファイルマネージャでアップロードしたファイルの場合、cmsフォルダは省略できます。</td></tr>
<tr><th>引数 (オプション): </th><td>画像のHTMLオプションを指定します。</td></tr>
<tr><th>戻り値: </th><td>画像リンク。</td></tr>
<tr><th>使用例: </th><td>* cmsフォルダを省略、HTMLオプションborderを指定<br/><br/>  &lt;ec:image_link src=&quot;logo.gif&quot; href=&quot;/&quot; border=&quot;1&quot;/&gt;<br/><br/>⇒<br/><br/>  &lt;a href=&quot;/&quot;&gt;<br/>    &lt;img border=&quot;1&quot; src=&quot;/cms/logo.gif&quot; alt=&quot;Logo&quot;/&gt;<br/>  &lt;/a&gt;<br/></td></tr>
EOS
      Test.descriptions[:foo].gsub(/\n/,'').should == expectation.gsub(/\n/,'')
    end

  end

  def ec
    helper.ec
  end

  describe 'bind_code_options' do
    it 'バインドの項目選択セレクトボックス用リスト取得' do
      expected_number = EcRider::EcHelper::ProductTag::PRODUCT_TAG_BIND_OPTION_METHODS.length +
                        EcRider::EcHelper::ShopTag::SHOP_TAG_BIND_OPTION_METHODS.length +
                        EcRider::EcHelper::UserLoginTag::USER_LOGIN_TAG_BIND_OPTION_METHODS.length
      result = EcRider::EcHelper::MethodDescription.bind_code_options
      result.length.should == expected_number
    end
  end

  describe 'bind_code_name' do
    it 'バインドの項目名取得' do
      EcRider::EcHelper::MethodDescription.bind_code_name('product_name_1').should == ['商品名1']
    end
  end
end
